@@ -19,13 +19,61 @@ import re
 from calculate.lib.datavars import (Variable, ReadonlyVariable,
                                     ReadonlyTableVariable, FieldValue,
                                     HumanReadable)
+from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.files import readFile
+from calculate.install.distr import DistributiveError
 
 from calculate.lib.cl_lang import setLocalTranslate, _
 
 setLocalTranslate('cl_install3', sys.modules[__name__])
 
 
+class VariableOsAudio(Variable):
+    """
+    Выбранная аудиосистема
+    """
+    type = "choice"
+    opt = ['--audio']
+    metavalue = "AUDIO"
+
+    def init(self):
+        self.label = _("Audio system")
+        self.help = _("set the audio system")
+
+    def get(self):
+        return self.choice()[0][0]
+
+    def set(self, value):
+        return {'none': ''}.get(value, value)
+
+    def choice(self):
+        return  self.Get('os_audio_available') or [('',_('None'))]
+
+
+class VariableOsAudioAvailable(Variable):
+    """
+    Доступные звуковые системы
+    """
+    type = "list"
+
+    def get(self):
+        mapAudioConf = (('pulseaudio', 'media-sound/pulseaudio',
+                       _("PulseAudio")),
+                      ('alsa', 'media-sound/alsa-utils', _('ALSA')))
+        image = self.Get('cl_image')
+        if image:
+            with image as distr:
+                try:
+                    distrPath = image.getDirectory()
+                    return map(lambda x:x[0::2],
+                               filter(lambda x: not x[1] or isPkgInstalled(x[1],
+                                                                           prefix=distrPath),
+                                      mapAudioConf))
+                except DistributiveError as e:
+                    pass
+        return sorted(map(lambda x:x[0::2], mapNetConf[-1:]), key=lambda x:x[1])
+
+
 class VariableOsAudioData(ReadonlyTableVariable):
     """
     Information about audio cards
@@ -99,7 +147,8 @@ class VariableOsAudioDefault(Variable):
     Current default audio card
     """
     type = "choice"
-    opt = ['--audio']
+    opt = ['--audio-card']
+    metavalue = "CARD"
 
     def init(self):
         self.label = _("Default audio card")
